@@ -25,6 +25,7 @@ from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.api_core import operations_v1  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.devtools.cloudbuild_v1.types import cloudbuild
 from google.longrunning import operations_pb2  # type: ignore
@@ -48,8 +49,6 @@ except AttributeError:
     except pkg_resources.DistributionNotFound:  # pragma: NO COVER
         _GOOGLE_AUTH_VERSION = None
 
-_API_CORE_VERSION = google.api_core.__version__
-
 
 class CloudBuildTransport(abc.ABC):
     """Abstract transport class for CloudBuild."""
@@ -67,6 +66,7 @@ class CloudBuildTransport(abc.ABC):
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -90,6 +90,8 @@ class CloudBuildTransport(abc.ABC):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
@@ -99,7 +101,7 @@ class CloudBuildTransport(abc.ABC):
         scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)
 
         # Save the scopes.
-        self._scopes = scopes or self.AUTH_SCOPES
+        self._scopes = scopes
 
         # If no credentials are provided, then determine the appropriate
         # defaults.
@@ -118,13 +120,20 @@ class CloudBuildTransport(abc.ABC):
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
 
+        # If the credentials are service account credentials, then always try to use self signed JWT.
+        if (
+            always_use_jwt_access
+            and isinstance(credentials, service_account.Credentials)
+            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
+        ):
+            credentials = credentials.with_always_use_jwt_access(True)
+
         # Save the credentials.
         self._credentials = credentials
 
-    # TODO(busunkim): These two class methods are in the base transport
+    # TODO(busunkim): This method is in the base transport
     # to avoid duplicating code across the transport classes. These functions
-    # should be deleted once the minimum required versions of google-api-core
-    # and google-auth are increased.
+    # should be deleted once the minimum required versions of google-auth is increased.
 
     # TODO: Remove this function once google-auth >= 1.25.0 is required
     @classmethod
@@ -145,27 +154,6 @@ class CloudBuildTransport(abc.ABC):
 
         return scopes_kwargs
 
-    # TODO: Remove this function once google-api-core >= 1.26.0 is required
-    @classmethod
-    def _get_self_signed_jwt_kwargs(
-        cls, host: str, scopes: Optional[Sequence[str]]
-    ) -> Dict[str, Union[Optional[Sequence[str]], str]]:
-        """Returns kwargs to pass to grpc_helpers.create_channel depending on the google-api-core version"""
-
-        self_signed_jwt_kwargs: Dict[str, Union[Optional[Sequence[str]], str]] = {}
-
-        if _API_CORE_VERSION and (
-            packaging.version.parse(_API_CORE_VERSION)
-            >= packaging.version.parse("1.26.0")
-        ):
-            self_signed_jwt_kwargs["default_scopes"] = cls.AUTH_SCOPES
-            self_signed_jwt_kwargs["scopes"] = scopes
-            self_signed_jwt_kwargs["default_host"] = cls.DEFAULT_HOST
-        else:
-            self_signed_jwt_kwargs["scopes"] = scopes or cls.AUTH_SCOPES
-
-        return self_signed_jwt_kwargs
-
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -208,6 +196,9 @@ class CloudBuildTransport(abc.ABC):
             self.retry_build: gapic_v1.method.wrap_method(
                 self.retry_build, default_timeout=600.0, client_info=client_info,
             ),
+            self.approve_build: gapic_v1.method.wrap_method(
+                self.approve_build, default_timeout=None, client_info=client_info,
+            ),
             self.create_build_trigger: gapic_v1.method.wrap_method(
                 self.create_build_trigger,
                 default_timeout=600.0,
@@ -362,6 +353,15 @@ class CloudBuildTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def approve_build(
+        self,
+    ) -> Callable[
+        [cloudbuild.ApproveBuildRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def create_build_trigger(
         self,
@@ -436,7 +436,7 @@ class CloudBuildTransport(abc.ABC):
         self,
     ) -> Callable[
         [cloudbuild.CreateWorkerPoolRequest],
-        Union[cloudbuild.WorkerPool, Awaitable[cloudbuild.WorkerPool]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
@@ -454,7 +454,7 @@ class CloudBuildTransport(abc.ABC):
         self,
     ) -> Callable[
         [cloudbuild.DeleteWorkerPoolRequest],
-        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
@@ -463,7 +463,7 @@ class CloudBuildTransport(abc.ABC):
         self,
     ) -> Callable[
         [cloudbuild.UpdateWorkerPoolRequest],
-        Union[cloudbuild.WorkerPool, Awaitable[cloudbuild.WorkerPool]],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
     ]:
         raise NotImplementedError()
 
