@@ -88,14 +88,14 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
             aio.Channel: A gRPC AsyncIO channel object.
         """
 
-        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
-
         return grpc_helpers_async.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
             quota_project_id=quota_project_id,
-            **self_signed_jwt_kwargs,
+            default_scopes=cls.AUTH_SCOPES,
+            scopes=scopes,
+            default_host=cls.DEFAULT_HOST,
             **kwargs,
         )
 
@@ -113,6 +113,7 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id=None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
@@ -136,16 +137,16 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
             api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                 If provided, it overrides the ``host`` argument and tries to create
                 a mutual TLS channel with client SSL credentials from
-                ``client_cert_source`` or applicatin default SSL credentials.
+                ``client_cert_source`` or application default SSL credentials.
             client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 Deprecated. A callback to provide client SSL certificate bytes and
                 private key bytes, both in PEM format. It is ignored if
                 ``api_mtls_endpoint`` is None.
             ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+                for the grpc channel. It is ignored if ``channel`` is provided.
             client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 A callback to provide client certificate bytes and private key bytes,
-                both in PEM format. It is used to configure mutual TLS channel. It is
+                both in PEM format. It is used to configure a mutual TLS channel. It is
                 ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
@@ -154,6 +155,8 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
 
         Raises:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
@@ -206,6 +209,7 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
             scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
 
         if not self._grpc_channel:
@@ -422,6 +426,38 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
             )
         return self._stubs["retry_build"]
 
+    @property
+    def approve_build(
+        self,
+    ) -> Callable[
+        [cloudbuild.ApproveBuildRequest], Awaitable[operations_pb2.Operation]
+    ]:
+        r"""Return a callable for the approve build method over gRPC.
+
+        Approves or rejects a pending build.
+        If approved, the returned LRO will be analogous to the
+        LRO returned from a CreateBuild call.
+
+        If rejected, the returned LRO will be immediately done.
+
+        Returns:
+            Callable[[~.ApproveBuildRequest],
+                    Awaitable[~.Operation]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "approve_build" not in self._stubs:
+            self._stubs["approve_build"] = self.grpc_channel.unary_unary(
+                "/google.devtools.cloudbuild.v1.CloudBuild/ApproveBuild",
+                request_serializer=cloudbuild.ApproveBuildRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["approve_build"]
+
     @property
     def create_build_trigger(
         self,
@@ -633,18 +669,15 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
     def create_worker_pool(
         self,
     ) -> Callable[
-        [cloudbuild.CreateWorkerPoolRequest], Awaitable[cloudbuild.WorkerPool]
+        [cloudbuild.CreateWorkerPoolRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the create worker pool method over gRPC.
 
-        Creates a ``WorkerPool`` to run the builds, and returns the new
-        worker pool.
-
-        This API is experimental.
+        Creates a ``WorkerPool``.
 
         Returns:
             Callable[[~.CreateWorkerPoolRequest],
-                    Awaitable[~.WorkerPool]]:
+                    Awaitable[~.Operation]]:
                 A function that, when called, will call the underlying RPC
                 on the server.
         """
@@ -656,7 +689,7 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
             self._stubs["create_worker_pool"] = self.grpc_channel.unary_unary(
                 "/google.devtools.cloudbuild.v1.CloudBuild/CreateWorkerPool",
                 request_serializer=cloudbuild.CreateWorkerPoolRequest.serialize,
-                response_deserializer=cloudbuild.WorkerPool.deserialize,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_worker_pool"]
 
@@ -666,9 +699,7 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
     ) -> Callable[[cloudbuild.GetWorkerPoolRequest], Awaitable[cloudbuild.WorkerPool]]:
         r"""Return a callable for the get worker pool method over gRPC.
 
-        Returns information about a ``WorkerPool``.
-
-        This API is experimental.
+        Returns details of a ``WorkerPool``.
 
         Returns:
             Callable[[~.GetWorkerPoolRequest],
@@ -691,16 +722,16 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
     @property
     def delete_worker_pool(
         self,
-    ) -> Callable[[cloudbuild.DeleteWorkerPoolRequest], Awaitable[empty_pb2.Empty]]:
+    ) -> Callable[
+        [cloudbuild.DeleteWorkerPoolRequest], Awaitable[operations_pb2.Operation]
+    ]:
         r"""Return a callable for the delete worker pool method over gRPC.
 
-        Deletes a ``WorkerPool`` by its project ID and WorkerPool name.
-
-        This API is experimental.
+        Deletes a ``WorkerPool``.
 
         Returns:
             Callable[[~.DeleteWorkerPoolRequest],
-                    Awaitable[~.Empty]]:
+                    Awaitable[~.Operation]]:
                 A function that, when called, will call the underlying RPC
                 on the server.
         """
@@ -712,7 +743,7 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
             self._stubs["delete_worker_pool"] = self.grpc_channel.unary_unary(
                 "/google.devtools.cloudbuild.v1.CloudBuild/DeleteWorkerPool",
                 request_serializer=cloudbuild.DeleteWorkerPoolRequest.serialize,
-                response_deserializer=empty_pb2.Empty.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_worker_pool"]
 
@@ -720,17 +751,15 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
     def update_worker_pool(
         self,
     ) -> Callable[
-        [cloudbuild.UpdateWorkerPoolRequest], Awaitable[cloudbuild.WorkerPool]
+        [cloudbuild.UpdateWorkerPoolRequest], Awaitable[operations_pb2.Operation]
     ]:
         r"""Return a callable for the update worker pool method over gRPC.
 
-        Update a ``WorkerPool``.
-
-        This API is experimental.
+        Updates a ``WorkerPool``.
 
         Returns:
             Callable[[~.UpdateWorkerPoolRequest],
-                    Awaitable[~.WorkerPool]]:
+                    Awaitable[~.Operation]]:
                 A function that, when called, will call the underlying RPC
                 on the server.
         """
@@ -742,7 +771,7 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
             self._stubs["update_worker_pool"] = self.grpc_channel.unary_unary(
                 "/google.devtools.cloudbuild.v1.CloudBuild/UpdateWorkerPool",
                 request_serializer=cloudbuild.UpdateWorkerPoolRequest.serialize,
-                response_deserializer=cloudbuild.WorkerPool.deserialize,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["update_worker_pool"]
 
@@ -755,9 +784,7 @@ class CloudBuildGrpcAsyncIOTransport(CloudBuildTransport):
     ]:
         r"""Return a callable for the list worker pools method over gRPC.
 
-        List project's ``WorkerPools``.
-
-        This API is experimental.
+        Lists ``WorkerPool``\ s.
 
         Returns:
             Callable[[~.ListWorkerPoolsRequest],
